/**
 * @file
 * Javascript for Color Field.
 */

(function ($, Drupal, drupalSettings, once) {

 

    window.NohasSwiperSlide = function(html) {
        if(!html){
            html = $('body');
        }
        
        $(html).find('.noahs_page_builder-slideshow').each(function (index, element) {
            $(this).attr('id', 'slide_' + index);
            if ($('#slide_' + index + ' .swiper-slide').length >= 1) {
                var slide = new Swiper('#slide_' + index, {
                    autoplay: {
                        delay: 5000,
                    },
                    pagination: {
                      el: ".swiper-pagination",
                    },
                    navigation: {
                        nextEl: '.swiper-button-next',
                        prevEl: '.swiper-button-prev', 
                    }
                });
            }
        });

        $(html).find('.noahs_page_builder-carousel').each(function (index, element) {
            $(this).attr('id', 'slide_carousel_' + index);
            if ($('#slide_carousel_' + index + ' .swiper-slide').length >= 1) {

                var show_items = $(this).data('show-items-desktop') ?? 4;
                var show_items_tablet = $(this).data('show-items-tablet') ?? 2;
                var show_items_mobile = $(this).data('show-items-mobile') ?? 1;
                var space = $(this).data('space') ?? 20;

                var slide = new Swiper('#slide_carousel_' + index, {
                    slidesPerView: show_items_mobile,
                    spaceBetween: space,
                    autoplay: {
                        delay: 5000,
                    },
                    pagination: {
                      el: ".swiper-pagination",
                      clickable: true,
                    },
                    navigation: {
                        nextEl: '.swiper-button-next',
                        prevEl: '.swiper-button-prev', 
                    },
                    breakpoints: {
                        768: {
                          slidesPerView: show_items_tablet,
                        },
                        1024: {
                          slidesPerView: show_items,
                        },
                      },
                });
            }
        });
        $(html).find('.testimonial-slider').each(function (index, element) {
            $(this).attr('id', 'testimonial_carousel_' + index);
            if ($('#testimonial_carousel_' + index + ' .swiper-slide').length >= 1) {
                var slide = new Swiper('#testimonial_carousel_' + index, {
                    slidesPerView: $(this).data('count-slide'),
                    spaceBetween: 0,
                    centeredSlides: true,
                    autoplay: {
                        delay: 5000,
                    },
                    pagination: {
                      el: ".swiper-pagination",
                    },
                    navigation: {
                        nextEl: '.swiper-button-next',
                        prevEl: '.swiper-button-prev', 
                    }
                });
            }
        });
        
        var today = new Date();
        var futureDate = new Date(today);
            futureDate.setDate(today.getDate() + 2);
        
        var timestamp = Math.floor(futureDate.getTime() / 1000);
        
        $(once('noahsCountDown', '.noahs_page_builder-countdown')).each(function (index, element) {
            var date = !$(this).is(':empty') && $(this).data('countdown') ? $(this).data('countdown') : timestamp;
            $(this).attr('id', 'flipdown_' + index);
            new FlipDown(date, "flipdown_" + index, {
                headings: [$(this).data('days'), $(this).data('hours'), $(this).data('minutes'), $(this).data('seconds')],
            }).start();
        });
        
        AOS.init();
        $('[data-background-parallax]').parallaxScroll();



    }
    $(window).resize(function(){
        actualizarAlturaHeader();
    });

    function actualizarAlturaHeader() {
        var alturaHeader = $('.noahs-pro-theme--header').height();
        $('#noahs_page_builder .builder-wrapper > section:first-child').css({
            'padding-top': 'calc(' + alturaHeader + 'px + 27px)'
        });
        
        $('#noahs_page_builder .builder-wrapper > section:first-child').children('.tab-noahs_row').css({
            'top': 'calc(' + alturaHeader + 'px - 27px)'
        });
    }

    $(document).ready(function() {
        actualizarAlturaHeader();

        var Noahsclasses = drupalSettings.noahs_page_builder.classes ?? [];

        $.each(Noahsclasses, function(index, values) {
            $.each(values, function(key, value) {
                $.each(value, function(selector, $class) {
                    $(selector).addClass($class);
                });
            });
        });   

        $.each(drupalSettings.noahs_page_builder.attributes, function(index, values) {
            $.each(values, function(key, value) {
               
                $.each(value, function(attr_, valor) {
                    $(key).attr(attr_, valor);
                });
              
            });
        });

        if (window.location.hash) {
            var hash = window.location.hash;
        
            if ($(hash).length) {
                $('html, body').animate({
                    scrollTop: $(hash).offset().top
                }, 900, 'swing');
            }
        }

        $('.accordion').on('shown.bs.collapse', function () {
            $(this).find('.accordion-header.active').removeClass('active'); // Elimina la clase 'active' de cualquier otro encabezado activo
            $(this).find('.accordion-button[aria-expanded="true"]').closest('.accordion-header').addClass('active'); // Agrega la clase 'active' al encabezado activo
          });

          $('.accordion').on('hidden.bs.collapse', function () {
            $(this).find('.accordion-header').removeClass('active'); // Elimina la clase 'active' cuando el cuerpo se colapsa
          });

      
        window.NohasSwiperSlide();
    });

    // Dropdown language
    $('.noahs-language-switcher.dropdown > .caption').on('click', function() {
        $(this).parent().toggleClass('open');
    });
    
    $('.noahs-language-switcher.dropdown > .list > .item').on('click', function() {
        $('.dropdown > .list > .item').removeClass('selected');
        $(this).addClass('selected').parent().parent().removeClass('open').children('.caption').text( $(this).text() );
    });
    
    $(document).on('keyup', function(evt) {
        if ( (evt.keyCode || evt.which) === 27 ) {
            $('.noahs-language-switcher.dropdown').removeClass('open');
        }
    });
    
    $(document).on('click', function(evt) {
        if ( $(evt.target).closest(".noahs-language-switcher.dropdown > .caption").length === 0 ) {
            $('.noahs-language-switcher.dropdown').removeClass('open');
        }
    });



    Drupal.behaviors.noahsCountDown = {
        attach: function(context, settings) {
        //    countDownd(context);
        }
    }


})(jQuery, Drupal, drupalSettings, once);



