<?php 

namespace Drupal\noahs_page_builder;
use Drupal\noahs_page_builder\Controls_Base;

class Control_Noahs_Divider extends Controls_Base{
	
	public function get_type() {
		return 'nohas_divider';
	}

	public function content_template($data, $name, $value) {

		$options = [
			'' => 'None',
			'tilt' => t('Tilt'),
			'waves' => t('Waves'),
			'waves_2' => t('Waves 2'),
			'waves_opaque' => t('Waves opaque'),
			'triangles' => t('Triangles'),
			'triangle' => t('Triangle'),
			'triangle_invert' => t('Triangle Invert'),
			'curve' => t('Curve'),
			'slash' => t('Slash'),
		];

		$items = Control_Noahs_Divider::list($name);

	
		$optionsAlign = [
			'center' => t('Center'),
			'left' => t('Left'),
			'right' => t('Right'),
		];

		$optionsDirection = [
			'' => 'Normal',
			'reverse' => 'Reverse',
		];
		?>
		<?php ob_start() ?>

		<ul class="nav nav-tabs noahs_page_builder-tabs" id="nav-tab-maks" role="tablist">
			<li class="nav-item">
    			<button class="nav-link active" id="nav-divider-top-tab" data-bs-toggle="tab" data-bs-target="#nav-divider-top" type="button" role="tab" aria-controls="nav-divider-top" aria-selected="true">Top</button>
			</li>
			<li class="nav-item">
    			<button class="nav-link" id="nav-divider-bottom-tab" data-bs-toggle="tab" data-bs-target="#nav-divider-bottom" type="button" role="tab" aria-controls="nav-divider-bottom" aria-selected="false">bottom</button>
			</li>
		</ul>

		<div class="tab-content" id="nav-tabContent">
			<div class="tab-pane fade show active  nohas-divider-controls" id="nav-divider-top" role="tabpanel" aria-labelledby="nav-divider-top-tab">
				<?php $this->generateOptionBlock($name, 'top', $value['top'], $options, $optionsDirection,$optionsAlign, $items); ?>
			</div>

			<div class="tab-pane fade nohas-divider-controls" id="nav-divider-bottom" role="tabpanel" aria-labelledby="nav-divider-bottom-tab">
				<?php $this->generateOptionBlock($name, 'bottom', $value['bottom'], $options, $optionsDirection,$optionsAlign, $items); ?>
			</div>
		</div>
		<?php return ob_get_clean();
	}

	private function generateOptionBlock($name, $type, $value, $options, $optionsDirection,$optionsAlign, $items) {
	
		$currentAlign = !empty($value['align']) ? $value['align'] : '';
		$currentDirection = !empty($value['direction']) ? $value['direction'] : '';
		$selected_value = !empty($value['divider']) ? $value['divider'] : '';

		?>
		<div class="media-preview-actions media-preview-actions--divider overflow-auto mb-3" style="height:200px">
			<div class="row g-3">
				<?php foreach($items as $k => $item){ 
					$checked = ($item['url'] === $value['divider']) ? 'checked' : '';
				?>
					<div class="col-12">
						<label for="mask-<?php echo $type; ?>-<?php echo $k; ?>">
							<input type="radio" data-type="<?php echo $type; ?>" id="mask-<?php echo $type; ?>-<?php echo $k; ?>" name="<?php echo $name; ?>[<?php echo $type; ?>][divider]" value="<?php echo $item['url']; ?>" <?php echo $checked; ?> field-setting>
							<?php echo $item['content']; ?>
						</label>
					</div>
				<?php }?>
			</div>
			<div class="btn-group position-absolute d-flex justify-content-between w-100">
				<button class="btn btn-danger media-remove_divider area_tooltip" title="" data-type="<?php echo $type; ?>"><i class="fa-solid fa-trash"></i></button>
			</div>
		</div>

		<div class="noahs-divider-styles" data-type="<?php echo $type; ?>">
			<div class="mb-3 d-flex gap-3">
				<div class="field__color col">
				
					<input type="text" name="<?php echo $name; ?>[<?php echo $type; ?>][color]" class="form-control-color noahs-divider-color" value="<?php echo !empty($value['color']) ? $value['color'] : null; ?>" field-settings>
					<label for="" class="form-label"><?php echo t('Color'); ?></label>
				</div>
				<div class="col">
					<input type="number" name="<?php echo $name; ?>[<?php echo $type; ?>][width]" min="0" value="<?php echo !empty($value['width']) ? $value['width'] : null; ?>" class="form-control noahs-divider-width" field-settings>
					<label for=""><?php echo t('Width'); ?></label>
				</div>
				<div class="col">
					<input type="number"  name="<?php echo $name; ?>[<?php echo $type; ?>][height]" value="<?php echo !empty($value['height']) ? $value['height'] : null; ?>" class="form-control noahs-divider-height" field-settings>
					<label for=""><?php echo t('Height') ; ?></label>
				</div>

			</div>

			<div class="mb-3 d-flex gap-3">
				<div class="col">
					<label class="form-label"><?php echo t('Direction'); ?></label>
					<select
						name="<?php echo $name; ?>[<?php echo $type; ?>][direction]"
						class="form-control form-select"
						field-settings="">
						<?php foreach ($optionsDirection as $key => $label): ?>
							<option value="<?php echo $key; ?>" <?php echo ($key == $currentDirection) ? 'selected' : ''; ?>>
								<?php echo $label; ?>
							</option>
						<?php endforeach; ?>
					</select>
				</div>
				<div class="col">
					<label class="form-label"><?php echo t('Align'); ?></label>
					<select
						name="<?php echo $name; ?>[<?php echo $type; ?>][align]"
						class="form-control form-select"
						field-settings="">
						<?php foreach ($optionsAlign as $key => $label): ?>
							<option value="<?php echo $key; ?>" <?php echo ($key == $currentAlign) ? 'selected' : ''; ?>>
								<?php echo $label; ?>
							</option>
						<?php endforeach; ?>
					</select>
				</div>
			</div>
		</div>
		<?php
	}
	public function render_control($data){
		return $this->base($data, $this->content_template($data));
	}

	private static function list($name = null) {
		$module_path = NOAHS_PAGE_BUILDER_PATH;
		$icon_folder_path = $module_path . '/assets/svg-divider-kit/';
		$file_system = \Drupal::service('file_system');
	
		$files = $file_system->scanDirectory($icon_folder_path, '/\.svg$/');
	
		$svg_data = array();
	
		foreach ($files as $file) {
			$svg_path = $file->uri;
			$svg_content = file_get_contents($svg_path);
			$svg_name = pathinfo($svg_path, PATHINFO_FILENAME);
			$svg_url = '/' . $file->uri;

			$svg_data[] = array(
				'name' => $svg_name,
				'url' => $svg_path,
				'content' => $svg_content
			);
		}
	
		return $svg_data;
	}

	protected function get_default_settings() {
		return [
			'input_type' => 'nohas_divider',
			'placeholder' => '',
			'title' => '',
		];
	}
}