<?php

namespace Drupal\noahs_page_builder\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\file\Entity\File;
use Drupal\image\Entity\ImageStyle;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\JsonResponse;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\File\FileSystem;
use Symfony\Component\HttpFoundation\Request;


class NoahsModalMediaController extends ControllerBase {

  public function mediaModal(Request $request) {

    $data = json_decode($request->getContent(), TRUE);
    $element_id = $data['element_id'];
    $wid = $data['wid'];

    $entity_type_manager = \Drupal::entityTypeManager();

    // Obtener el almacenamiento de archivos según la fuente.
    if ($data['source'] === 'video') {
      $file_mime_types = ['video/mp4', 'video/webm'];
    } elseif ($data['source'] === 'image') {
      $file_mime_types = ['image/jpeg', 'image/gif', 'image/png'];
    }
    
    // Crear una consulta para los archivos.
    $query = $entity_type_manager->getStorage('file')
      ->getQuery()
      ->condition('filemime', $file_mime_types, 'IN')
      ->accessCheck(FALSE)
      ->sort('created', 'DESC'); // Ordenar por fecha de subida, los más recientes primero.
    
    // Ejecutar la consulta.
    $file_ids = $query->execute();
    
    // Obtener los archivos.
    $files = $entity_type_manager->getStorage('file')->loadMultiple($file_ids);
    
    // Agrupar los archivos por mes.
    $files_grouped_by_month = [];
    foreach ($files as $file) {
      // Obtener la fecha de subida del archivo.
      $created_date = \Drupal::service('date.formatter')->format($file->getCreatedTime(), 'custom', 'Y-m');
      
      // Agrupar el archivo por mes.
      $files_grouped_by_month[$created_date][] = $file;
    }



    // Preparar el HTML para la lista de miniaturas.
    $html = '<div class="noahs_page_builder-media-modal modal-type-'. $data['type'] .'">';
    $html .= '<div class="noahs_page_builder-modal_container">';
    $html .= '<div class="noahs-new-media-element"></div>';
    $html .= '<div class="p-4">';
    foreach ($files_grouped_by_month as $month_date => $months) {
      $html .= '<div class="row mb-2">';
      $html .= '<p class="m-0">' . $month_date . '</p>';
      foreach ($months as $file) {
        $file_uri = $file->getFileUri();
        if($data['source'] === 'image'){
          $image_style_url = ImageStyle::load('thumbnail')->buildUrl($file_uri);
          $html .= '<div class="col-2 image-box mb-2" data-fileid="'.$file->id().'" data-thumbnail="'.$image_style_url.'"><span><img src="' . $image_style_url . '" alt="Thumbnail"></span></div>';
        }
        if($data['source'] === 'video'){

          $file_name = $file->filemime->value;
          $video_local_url = \Drupal::service('file_url_generator')->generateAbsoluteString($file_uri);
          $html .= '<div class="col-2 image-box mb-2 image-box-video" data-thumbnail="'.$video_local_url.'" data-fileid="'.$file->id().'">';
          $html .= '<video class="noahs-video-iframe" width="100%">
                    <source src="'. $video_local_url .'" type="'.$file_name.'">
                    <p>Su navegador no soporta vídeos HTML5.</p>
                  </video></div>';
        }
      }
      $html .= '</div>';
    }
    $html .= '</div>';
    $html .= '<div class="noahs-media-modal-actions px-4 mt-4 bg-white pt-2 pb-2">';
    $html .= '<div class="upload-image">
              <form id="noahs_page_builderUploadImageForm" enctype="multipart/form-data">
              <label>'.t('Upload Media').'</label>
              <input type="file" id="noahs_page_builder_upload_image" name="noahs_page_builder_upload_image" '.$data['type'].' title="Upload Media" accept="image/png, image/gif, image/jpeg, video/mp4, video/webm" class="form-control">
              </form>
              </div>';


    $html .= '<div class="modal-messages"></div>';
    $html .= '<div class="d-flex justify-content-between mt-3">';
    $html .= '<button class="btn btn-danger btn-labeled close-media-modal"><span class="btn-label"><i class="fa-solid fa-xmark"></i></span>Close</button>
    <button type="button" class="btn btn-success btn-labeled insert-media-modal" data-wid="'.$wid.'" data-element-id="'.$element_id.'" data-thumbnail=""><span class="btn-label"><i class="fa-solid fa-check"></i></span>'.t("Insert selected").'</button>';
    $html .= '</div>';
    $html .= '</div>';
    $html .= '</div>';

    return new JsonResponse(['html' => $html, 'data' => $data ]); 
  }
  
  public function uploadMediaModal() {
    $files = $_FILES['files'] ?? null;
    $current_date = \Drupal::time()->getCurrentTime();
    $current_month = date('Y-m', $current_date);

    $directory = 'public://' . $current_month;
    $file_system = \Drupal::service('file_system');
    $file_system->prepareDirectory($directory, FileSystemInterface::CREATE_DIRECTORY | FileSystemInterface::MODIFY_PERMISSIONS | FileSystemInterface::EXISTS_RENAME);

    $uploaded_files = [];

    foreach ($files['name'] as $key => $filename) {
        $filedata = file_get_contents($files['tmp_name'][$key]);
        $directory_url = $directory . '/' . $filename;

        $uploaded_file = \Drupal::service('file_system')->saveData($filedata, $directory_url, FileSystemInterface::EXISTS_RENAME);

        $file = File::create([
            'uri' => $uploaded_file,
        ]);
        $file->setPermanent();
        $file->save();
        $image_style_url  = '';
        $media_url = \Drupal::service('file_url_generator')->generateAbsoluteString($file->getFileUri());
        if($file->getMimeType() != "image/svg+xml"){
          $image_style_url = ImageStyle::load('thumbnail')->buildUrl($file->getFileUri());
        }
        $file_name = $file->filemime->value;
        $uploaded_files[] = [
            'file_id' => $file->id(),
            'file_url' => $image_style_url,
            'file_name' => $file_name,
            'file_type' => $file->getMimeType(),
            'file_fullurl' => $media_url,
        ];
    }

    if (empty($uploaded_files)) {
        return new JsonResponse(['message' => 'No se ha enviado ningún archivo.'], 400);
    }

    return new JsonResponse(['message' => 'Archivos subidos correctamente.', 'files' => $uploaded_files]);
}

}